<!--
        Licensed Material - Property of IBM
        5630-A36, 5655-I35 (C) Copyright IBM Corp. 2000-2004

        All Rights Reserved.

        U.S. Government users - RESTRICTED RIGHTS - Use, Duplication, or
        Disclosure restricted by GSA-ADP schedule contract with IBM Corp.

        Status = H28W500
        WAS390
        LIDB2775.89.1 - re-sync with zwas510 (complete replacement)
-->
<xsl:stylesheet version="1.0"
    xmlns:xmi="http://www.omg.org/XMI"
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xalan="http://xml.apache.org/xslt"
    xmlns:variables="http://www.ibm.com/websphere/appserver/schemas/5.0/variables.xmi"
    xmlns:C2N="com.ibm.ws.management.util.zos.gate">

    <!-- import shared -->
    <xsl:include href="shared.xsl"/>

        <!-- Build the Key Space -->
        <xsl:key name="keys" match="//entries" use="@symbolicName"/>


        <xsl:template match="/">
                <xsl:apply-templates select="xmi:XMI" />
                <xsl:apply-templates select="variables:VariableMap"/>
        </xsl:template>


        <!-- Match on the "xmi:XMI" -->
        <xsl:template match="xmi:XMI">
                <xsl:apply-templates select="xmi:Documentation"/>
                <xsl:apply-templates select="variables:VariableMap"/>
        </xsl:template>

        <!-- Just swallowing this, here for completeness -->
        <xsl:template match="xmi:Documentation"></xsl:template>

        <!-- Matches the tag <variables:VariableMap> -->
        <!-- Function Parse is called inside -->
        <xsl:template match="variables:VariableMap">
                <xsl:for-each select="entries">
                        <xsl:choose>
                                <xsl:when test="@symbolicName = 'WAS_SERVER_ONLY_default_jvm_options'">
                                        <xsl:value-of select="C2N:Catcher.addJVMOption('control.jvm.options',$GenKey,@value)"/>
                                        <xsl:value-of select="C2N:Catcher.addJVMOption('servant.jvm.options',$GenKey,@value)"/>
                                        <xsl:value-of select="C2N:Catcher.addJVMOption('adjunct.jvm.options',$GenKey,@value)"/>
                                        
                                        <!-- PM92206: add the default jvm property in for all three Z/OS regions -->
                                        <xsl:value-of select="C2N:Catcher.addJVMOption('control.jvm.options',$GenKey,'-Dcom.ibm.xtq.processor.overrideSecureProcessing','true')"/>
                                        <xsl:value-of select="C2N:Catcher.addJVMOption('servant.jvm.options',$GenKey,'-Dcom.ibm.xtq.processor.overrideSecureProcessing','true')"/>
                                        <xsl:value-of select="C2N:Catcher.addJVMOption('adjunct.jvm.options',$GenKey,'-Dcom.ibm.xtq.processor.overrideSecureProcessing','true')"/>
                                </xsl:when>
                                <xsl:when test="@symbolicName = 'WAS_SERVER_ONLY_control_region_classpath'">
                                        <xsl:value-of select="C2N:Catcher.addToList($GenKey,'control_region_classpath', @value)"/>
                                </xsl:when>
                                <xsl:when test="@symbolicName = 'WAS_SERVER_ONLY_server_region_classpath'">
                                        <xsl:value-of select="C2N:Catcher.addToList($GenKey,'server_region_classpath', @value)"/>
                                        <xsl:value-of select="C2N:Catcher.addToList($GenKey,'adjunct_region_classpath', @value)"/>
                                </xsl:when>
                                <xsl:when test="@symbolicName = 'WAS_SERVER_ONLY_control_region_libpath'">
                                        <xsl:value-of select="C2N:Catcher.addToList($GenKey,'control_region_libpath', @value)"/>
                                </xsl:when>
                                <xsl:when test="@symbolicName = 'WAS_SERVER_ONLY_server_region_libpath'">
                                        <xsl:value-of select="C2N:Catcher.addToList($GenKey,'server_region_libpath', @value)"/>
                                        <xsl:value-of select="C2N:Catcher.addToList($GenKey,'adjunct_region_libpath', @value)"/>
                                </xsl:when>

                                <xsl:otherwise>
                                        <xsl:variable name="currentName" select="@symbolicName"/>
                                        <xsl:variable name="currentValue" select="@value"/>
                                        <xsl:call-template name="parse">
                                                <xsl:with-param name="symName" select="$currentName"/>
                                                <xsl:with-param name="curValue" select="$currentValue"/>
                                        </xsl:call-template>
                                </xsl:otherwise>
                        </xsl:choose>
                </xsl:for-each>
        </xsl:template>

        <!-- Recursive function that actually does the parsing -->
        <xsl:template name="parse">
                <xsl:param name="symName"/>
                <xsl:param name="curValue"/>
                <xsl:choose>
                        <xsl:when test="contains($curValue, '$')">
                                <xsl:variable name="after" select="substring-after($curValue, '}')"/>
                                <xsl:variable name="before_messy" select="substring-before($curValue, '}')"/>
                                <xsl:variable name="before_clean" select="substring-after($before_messy, '{')"/>

                                <!-- start key block -->
                                <xsl:for-each select="key('keys', $before_clean)">
                                        <xsl:variable name="insert" select="@value"/>
                                        <xsl:variable name="final" select="concat($insert, $after)"/>
                                        <xsl:choose>
                                                <xsl:when test="contains($final, '$')">
                                                <!-- final still has a $, recall function -->
                                                        <xsl:call-template name="parse">
                                                                <xsl:with-param name="symName" select="$symName"/>
                                                                <xsl:with-param name="curValue" select="$final"/>
                                                        </xsl:call-template>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                        <xsl:call-template name="print">
                                                                <xsl:with-param name="key" select="$symName"/>
                                                                <xsl:with-param name="value" select="$final"/>
                                                        </xsl:call-template>
                                                </xsl:otherwise>
                                        </xsl:choose>
                                </xsl:for-each>

                                <!-- no match found in the current level, search previous -->
                                <xsl:call-template name="print">
                                        <xsl:with-param name="key" select="$symName"/>
                                        <xsl:with-param name="value" select="$curValue"/>
                                </xsl:call-template>
                                <!-- end key block -->
                                </xsl:when>
                                <xsl:otherwise>
                                        <xsl:call-template name="print">
                                                <xsl:with-param name="key" select="$symName"/>
                                                <xsl:with-param name="value" select="$curValue"/>
                                        </xsl:call-template>
                                </xsl:otherwise>
                </xsl:choose>
        </xsl:template>

        <!-- Print template-->
        <xsl:template name="print">
                <xsl:param name="key"/>
                <xsl:param name="value"/>
                <xsl:choose>
                        <xsl:when test="$mode = 'daemon'">
                            <xsl:choose>
                                <xsl:when test="starts-with($key, 'was.DAEMON_')">
                                    <xsl:value-of select="C2N:Catcher.saveKeyValue($GenKey, substring-after($key, 'was.'), $value)"/>
                                </xsl:when>
                                <xsl:when test="starts-with($key, 'was.WAS_DAEMON_ONLY_')">
                                    <xsl:value-of select="C2N:Catcher.saveKeyValue($GenKey, substring-after($key, 'was.'), $value)"/>
                                </xsl:when>
                                <xsl:when test="starts-with($key, 'was.WAS_DAEMON_')">
                                    <xsl:value-of select="C2N:Catcher.saveKeyValue($GenKey, substring-after($key, 'was.'), $value)"/>
                                </xsl:when>

                                <xsl:when test="starts-with($key, 'DAEMON_')">
                                    <xsl:value-of select="C2N:Catcher.saveKeyValue($GenKey, $key, $value)"/>
                                </xsl:when>
                                <xsl:when test="starts-with($key, 'WAS_DAEMON_ONLY_')">
                                    <xsl:value-of select="C2N:Catcher.saveKeyValue($GenKey, $key, $value)"/>
                                </xsl:when>
                                <xsl:when test="starts-with($key, 'WAS_DAEMON_')">
                                    <xsl:value-of select="C2N:Catcher.saveKeyValue($GenKey, $key, $value)"/>
                                </xsl:when>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:when test="$mode = 'servers'">
                            <xsl:choose>

                                <xsl:when test="starts-with($key, 'was.WAS_DAEMON_ONLY_')">
                                </xsl:when>

                                <xsl:when test="starts-with($key, 'was.WAS_DAEMON_')">
                                    <xsl:value-of select="C2N:Catcher.saveKeyValue($GenKey, substring-after($key, 'was.'), $value)"/>
                                </xsl:when>

                                <xsl:when test="starts-with($key, 'was.DAEMON_')">
                                </xsl:when>


                                <xsl:when test="starts-with($key, 'WAS_SERVER_ONLY_')">
                                    <xsl:value-of select="C2N:Catcher.saveKeyValue($GenKey, $key, $value)"/>
                                </xsl:when>


                                <xsl:when test="starts-with($key, 'WAS_DAEMON_ONLY_')">
                                </xsl:when>

                                <xsl:when test="starts-with($key, 'WAS_DAEMON_')">
                                    <xsl:value-of select="C2N:Catcher.saveKeyValue($GenKey, $key, $value)"/>
                                </xsl:when>

                                <xsl:when test="starts-with($key, 'DAEMON_')">
                                </xsl:when>


                                <xsl:when test="starts-with($key, 'WAS_SERVER_ONLY_')">
                                    <xsl:value-of select="C2N:Catcher.saveKeyValue($GenKey, $key, $value)"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="C2N:Catcher.saveKeyValue($GenKey,$key, $value)"/>
                                </xsl:otherwise>
                            </xsl:choose>

                        </xsl:when>
                </xsl:choose>

        </xsl:template>
</xsl:stylesheet>
